@@ -78,8 +78,16 @@
 class JustpyCore {
  
   // create a JustpyCore instance
-  constructor(page_options) {
-    this.page_options=page_options
+  constructor(window,title,debug) {
+	this.window=window
+    this.setTitle(title);
+    this.debug=debug
   }
   
+  // set the title
+  setTitle(title) {
+	document.title=title;
+	this.title=title;
+	// pass
+  }
 }
\ No newline at end of file
